//MainWindow.h: Header file for main application window class.

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui/QWidget>
#include <QtGui/QMainWindow>
#include <QtGui/QMenuBar>
#include <QtGui/QAction>
#include <QtGui/QGridLayout>
#include <QtGui/QListView>
#include <QStandardItemModel>
#include <QModelIndex>
#include <QStandardItem>
#include <QtGui/QListWidget>
#include <QtGui/QListWidgetItem>
#include <QtGui/QLabel>
#include <QtGui/QLineEdit>
#include <QtGui/QPushButton>
#include <QtGui/QKeyEvent>
#include <QtGui/QCloseEvent>
#include <QtGui/QProgressBar>
#include <QSettings>
#include <QMessageBox>
#include <QFont>
#include <QTranslator>
#ifdef Q_WS_MAEMO_5
    #include <QtMaemo5/QMaemo5InformationBox>
#else
    #include "Banner.h"
#endif
#include <QMessageBox>
#include <qspotify_src/spotifysession.h>
#include "logindialog.h"
#include "SettingsDialog.h"
#include "TrackView.h"
#include "AlbumView.h"
#include "QueueView.h"
#include "artistview.h"
#include "AboutDialog.h"
#include "SpectrumAnalyzer.h"
#include "customlabel.h"
#include "OssoWrapper.h"
#include "lastfmscrobbler.h"
#include "DBusWrapper.h"
#include "global_defs.h"
#include "HelpViewer.h"


//defines

#define APP_VERSION "1.1.0-1" //application version string

//menu bar actions
#define MENU_ACTION_SETTINGS        0
#define MENU_ACTION_FM_TRANSMITTER  1
#define MENU_ACTION_ONLINE_HELP     2
#define MENU_ACTION_ABOUT           3
#define MENU_ACTION_LOGOUT          4
#define MENU_ACTION_OFFLINE_MODE    5

class MainWindow : public QMainWindow
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.maemo.qspot")

public:
    MainWindow(QWidget *parent = 0);
    ~MainWindow();

protected:

    void keyPressEvent(QKeyEvent *evt);
    void closeEvent(QCloseEvent *);

private:

    QSettings* m_pAppSettings; //application settings instance

    QMenu* m_pCtxMenu; //context menu (options for i.e., offline synchronisation)

    QProgressBar *m_pSyncProgress; //progressbar used to display progress of offline sync operation

    QWidget m_MainLayout;

    QGridLayout m_GridLayout;

    QTranslator m_appTranslator;

    HelpViewer* m_pHelpViewer; //online help viewer instance

    LoginDialog* m_pLoginDlg;// login dialog instance

    SettingsDialog* m_pSettingsDlg; //settings dialog instance

    TrackView* m_pTrackView; //artist view instance

    AlbumView* m_pAlbumView; //album view instance

    QueueView* m_pQueueView; //playqueue (Now Playing) view instance

    ArtistView* m_pArtistView; //artist view instance

    Spotify::Session* m_pSession; //main Spotify session instance (handles communication with Spotify backend)

    OssoWrapper* m_pOssoWrapper; //wrapper instance for libosso

    DBusWrapper* m_pDBusWrapper; //wrapper instance for D-bus interface

    LastFMScrobbler* m_pLastFMScrobbler; //Last.fm scrobbling instance

    QPushButton m_SearchBtn;

    QLineEdit m_SearchInput;

    QStandardItemModel *m_pPlaylistModel;

    ListViewDelegate *m_pPlaylistDelegate;

    QListView* m_pPlaylistView;

    QListWidget m_PlaylistInfo;

    CustomLabel m_NowPlayingIcon;

    QFont m_NowPlayingFont;

    CustomLabel m_NowPlayingInfo;

    CustomLabel m_NowPlayingPositionInfo;

    QString m_strNowPlayingInfo;

    SpectrumAnalyzer* m_pSpectrum; //spectrum analyzer widget

    QList<Spotify::Playlist*> m_Playlists; //list holding pointers to playlist instances

    QList<Spotify::Track*> m_PlayQueue; //current playqueue

    qint32 m_currQueuePos; //current position in the play queue (position of track being played)

    bool m_playing; //TRUE if in playing mode

    bool m_update; //TRUE in case UI elements should be updated

    bool m_LastfmScrobblingEnabled; //TRUE in case Last.fm scrobbling enabled

    qint64 m_currPlaybackPos; //playback position for currently playing track

    AboutDialog m_AboutDlg; //App About dialog instance

    quint32 m_currSysVolume; //current system volume (used for volume control using HW zoom keys when screen is in locked state)

    qint32 m_currOrientation; //current display orientation

    QAction* m_pSettingsAction; //action associated with Settings menu entry

    QAction* m_pAboutAction; //action associated with About menu entry

    QAction* m_pHelpAction; //action associated with Help menu entry
#ifdef Q_WS_MAEMO_5
    QAction* m_pFMTransAction; //action associated with FM Transmitter menu entry
#endif

    QAction* m_pLogoutAction; //action associated with the Log Out menu entry

    QAction* m_pOnlineStateAction; //action associated with the Go Offline / Go Online menu entry

    void logout(); //logout current user and display the login dialog

    void showAboutDialog(); //display the application about dialog

    void updateSettings();  //update / set application-related settings

    void setupInitialState(); //set up the app initial state (audio etc.)

    void setDisplayOrientation(qint32 orientation); //set the display orientation

    void setupUILang(); //setup the UI language

    void updatePlaylistModel(); //update the listmodel from underlying playlist instances


private slots:

     void OnShowLogin();
     void OnHandleLoginType(); //slot for detecting / handling automatic / manual login to Spotify
     void OnLoginResponse(Spotify::Error error);
     void OnLoggedOut();
     void OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists);
     void OnPlaylistActivated(QModelIndex index);
     void OnPlaylistAdded(Spotify::Playlist* playlist, qint32 position); //a playlist has been added
     void OnPlaylistRemoved(qint32 position); //a playlist has been removed
     void OnPlaylistUpdated(); //a playlist (e.g., metadata) has been updated
     void OnLoginDialogRejected();
     void OnMainMenuAction(QAction* action);
     void OnPlayingState(bool state);
     void OnSetPlayQueue(const QList<Spotify::Track*>& queue, qint32 currQueuePos);
     void OnPlayQueuePosUpdated(qint32 pos);
     void OnNowPlaying();
     void OnSearch();
     void OnSearchComplete(Spotify::Search* search);
     void OnPlaybackPositionUpdated(qint64 pos);
     void OnPlaybackTokenLost();
     void OnSettingsSaved();
     void OnDisplayFMTransmitterDialog();
     void OnShowAlbumView(Spotify::Album* pAlbum);
     void OnShowArtistView(Spotify::Artist* pArtist);
     void OnScrobblingStatus(bool status, const QString& error);
     void OnScrobbleUpdateNowPlaying(const QString& strTrackName, const QString& strArtistName, const QString& strAlbumName, const QString& strAlbumArtist); //update Last.fm now playing info
     void OnScrobbleTrack(); //scrobble current track to Last.fm (and send scrobbles in queue)
     void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
     void OnDisplayStateChanged(bool state); //display state changed notification (i.e., true=ON, false=OFF)
#ifdef Q_WS_MAEMO_5
     void OnHWZoomKeyPressed(quint32 keycode); //notification that HW zoom key has been pressed
#endif
     void OnSpotifyLogin(const QString& strUserID, const QString& strPassword, bool saveCredentials); //slot for handling login to the Spotify backend service
     void OnContextMenuRequested(QPoint pnt);
     void OnOfflineSyncStatusUpdated(bool newSync, qint32 progress); //invoked when offline sync status is updated for update of operation progress (first param. indicates whether new sync operation; second param progress in percentage)
     void OnOfflineModeStateChanged(bool offline); //notification received when current offline state has changed (e.g., online -> offline)
     void OnOfflineSyncError(const QString& strError); //notification about offline sync. error
     void OnOfflineModeStateToggled(bool checked); //user has manually toggled between offline / online states

signals:

     void showLogin();
};

#endif // MAINWINDOW_H
